pilas.actores.animacion.Animacion

Package pilas :: Package actores :: Module animacion :: Class Animacion |
[hide private]
[frames] | no frames]

# Class Animacion

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                  animado.Animado --+
                                    |
                                   Animacion

Known Subclasses:
  - navekids.NaveKids
  - , explosion.Explosion
  - , bomba.Bomba
  - , moneda.Moneda
  - , nave.Nave
  - , humo.Humo
  - , proyectil.Dinamita
  - , proyectil.Misil

Representa una animacion de una grilla de imagenes.

Este actor toma una grilla de cuadros de animacion y los reproduce hasta que la animacion termina. Cuando la animacion termina se elimina a si mismo.

El constructor tiene algunos parámetros de utilidad:

- El parámetro ``ciclica`` permite hacer animaciones infinitas, que se repiten siempre, por defecto vale ``False`` que significa que la animación terminará y no se repetirá.
- El parámetro ``velocidad`` tiene que ser un número que indicará la cantidad de cuadros por segundo que se tienen que mostrar en la animación.

  Por ejemplo, para mostrar una explosión infinita podrías escribir:

      >>> grilla = pilas.imagenes.cargar_grilla("explosion.png", 7)
      >>> animacion = pilas.actores.Animacion(grilla, ciclica=True, velocidad=1)

  .. image:: images/actores/explosion.png

Instance Methods | [hide private]
__init__(self, grilla, ciclica=False, x=0, y=0, velocidad=10) Constructor de la Animación. | source code
actualizar(self) Hace avanzar la animacion. | source code
definir_velocidad_de_animacion(self, velocidad_de_animacion) Define la cantidad de frames por segundo que se mostrarán. | source code
obtener_velocidad_de_animacion(self) Obtiene la cantidad de cuadros por segundo de la animacion. | source code
Inherited from `animado.Animado`: `definir_cuadro` Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
| velocidad_de_animacion Es la cantidad de cuadros por segundo a mostrar
Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, grilla, ciclica=False, x=0, y=0, velocidad=10) (Constructor) | source code
Constructor de la Animación. :param grilla: Grilla de imagenes obtenida mediante pilas.imagenes.cargar_grilla() :type grilla: `Grilla` :param ciclica: Indica si la animación se realizará de forma infinita. :type ciclica: boolean :param x: Posicion horizontal del Actor. :type x: int :param y: Posicion vertical del Actor. :type y: int :param velocidad: Indica la cantidad de cuadros por segundo que se monstrarán. :type velocidad: int Overrides: estudiante.Estudiante.__init__

### actualizar(self) | source code
Hace avanzar la animacion. Overrides: actor.Actor.actualizar

### definir_velocidad_de_animacion(self, velocidad_de_animacion) | source code
Define la cantidad de frames por segundo que se mostrarán. :param velocidad_de_animacion: Cantidad de cuadros por segundo. :type velocidad_de_animacion: int

### obtener_velocidad_de_animacion(self) | source code
Obtiene la cantidad de cuadros por segundo de la animacion. :return: int

Property Details | [hide private]

### velocidad_de_animacion Es la cantidad de cuadros por segundo a mostrar Get Method: obtener_velocidad_de_animacion(self) - Obtiene la cantidad de cuadros por segundo de la animacion. Set Method: definir_velocidad_de_animacion(self, velocidad_de_animacion) - Define la cantidad de frames por segundo que se mostrarán.